---------------
SPT-3G Software
---------------

The SPT-3G analysis and data acquisition software uses pipelines that hand frames containing data between a series of modules. Documentation both on the framework and data processing modules is below. The top contains a set of general overview documents, while the bottom of this page contains more specific information on individual code modules.  All of the data types that can be stored in frames are listed in the "Frame Objects" part of the individual module documentation.

.. toctree::
	:maxdepth:	1
	:caption:	General Documentation

	quickstart
	modules
	frames
	logging
	fileio
	units
	dataacquisition
	autodoc
	buildsystem
	styleguide
	networkstreaming
	commonissues

.. toctree::
	:maxdepth:	1
	:caption:	Module Documentation
	:glob:

	moddoc_*

Documentation in this section is autogenerated from the source code and contains documentation on all pipeline modules, frame objects, classes and functions marked as part of a public API in all code.
